C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LDM_GET_IMDAT    **
C**************************
C
C
CD-Doc:
C IMAGE_Data       SUBROUTINE LDM_GET_IMDAT (VALSTR, IVAL, IFLAG)
CD-end
      SUBROUTINE LDM_GET_IMDAT (VALSTR, IVAL, IFLAG)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Get value of string/code parameter IMAGE_DATA
C
C Author:  John W. Campbell, July 1994
C
C Arguments:
C
      CHARACTER*(*) VALSTR
      INTEGER IVAL
      INTEGER IFLAG

C  VALSTR    (W)   Value for the parameter as a string 'byte', 'i2',
C                  'mar', 'pfbyte' ... or site specific string of
C                  form site:type  
C  IVAL      (W)   Code number 1=byte, 2=i2, 3=mar, 4=pfbyte
C                              0 = site specific code (use returned string)
C  IFLAG     (W)   Flag = -1 undefined value
C                       =  0 default value
C                       =  1 value set explicitly
C                       =  2 value set globally
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C
C
C-------------------------------------------------------------------------------
C
      IVAL = IMDAT
      VALSTR = IMDAT_STR
      IFLAG = IS_IMDAT
      RETURN
      END
